@@ -4,7 +4,7 @@ use super::*;
 impl<T> ListFn for Option<T> {
     type Item = T;
     type End = Self;
-    fn state(self) -> ListState<Self> {
+    fn next(self) -> ListState<Self> {
         match self {
             Option::Some(first) => ListState::Some(first, Option::None),
             Option::None => ListState::End(Option::None),
